@@ -158,7 +158,7 @@ void FakeManager::plug(const QString &udi)
     if (d->hiddenDevices.contains(udi)) {
         QMap<QString, QVariant> properties = d->hiddenDevices.take(udi);
         d->loadedDevices[udi] = new FakeDevice(udi, properties);
-        emit deviceAdded(udi);
+        Q_EMIT deviceAdded(udi);
     }
 }
 
@@ -167,7 +167,7 @@ void FakeManager::unplug(const QString &udi)
     if (d->loadedDevices.contains(udi)) {
         FakeDevice *dev = d->loadedDevices.take(udi);
         d->hiddenDevices[udi] = dev->allProperties();
-        emit deviceRemoved(udi);
+        Q_EMIT deviceRemoved(udi);
         delete dev;
     }
 }
@@ -198,7 +198,7 @@ void FakeManager::parseMachineFile()
             if (tempDevice) {
                 Q_ASSERT(!d->loadedDevices.contains(tempDevice->udi()));
                 d->loadedDevices.insert(tempDevice->udi(), tempDevice);
-                emit deviceAdded(tempDevice->udi());
+                Q_EMIT deviceAdded(tempDevice->udi());
             }
         }
 
