@@ -1,22 +1,8 @@
 /*
-    Copyright 2006-2010 Kevin Ottens <ervin@kde.org>
-    Copyright 2010 Mario Bensi <mbensi@ipsquad.net>
+    SPDX-FileCopyrightText: 2006-2010 Kevin Ottens <ervin@kde.org>
+    SPDX-FileCopyrightText: 2010 Mario Bensi <mbensi@ipsquad.net>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "fstabhandling.h"
@@ -116,6 +102,7 @@ bool _k_isFstabNetworkFileSystem(const QString &fstype, const QString &devName)
             || fstype == "nfs4"
             || fstype == "smbfs"
             || fstype == "cifs"
+            || fstype == "fuse.sshfs"
             || devName.startsWith(QLatin1String("//"))) {
         return true;
     }
@@ -139,7 +126,11 @@ QString _k_deviceNameForMountpoint(const QString &source, const QString &fstype,
         fstype == QLatin1String("overlay")) {
             return fstype + mountpoint;
     }
-    return source;
+    // A source may be mounted several times, e.g. with different
+    // options, often a network share with different credentials
+    // for different users. Make sure it is unique by appending the
+    // mountpoint (which is unique).
+    return source + QLatin1Char(':') + mountpoint;
 }
 
 void Solid::Backends::Fstab::FstabHandling::_k_updateFstabMountPointsCache()
